@@ -1,5 +1,7 @@
+mod include;
 extern crate rbspy;
 
+use crate::include::path_to_ruby_binary;
 use rbspy::recorder::{RecordConfig, Recorder};
 use rbspy::OutputFormat;
 
@@ -20,6 +22,7 @@ fn main() {
         maybe_duration: Some(std::time::Duration::from_secs(1)),
         flame_min_width: 10.0,
         lock_process: true,
+        force_version: None,
     };
     let recorder = Recorder::new(config);
     match recorder.record() {
@@ -32,25 +35,3 @@ fn main() {
 
     process.kill().expect("couldn't clean up ruby process");
 }
-
-fn path_to_ruby_binary() -> String {
-    let which = if cfg!(target_os = "windows") {
-        "C:\\Windows\\System32\\WHERE.exe"
-    } else {
-        "/usr/bin/which"
-    };
-
-    let output = std::process::Command::new(which)
-        .arg("ruby")
-        .output()
-        .expect("failed to execute process");
-
-    let ruby_binary_path = String::from_utf8(output.stdout).unwrap();
-
-    let ruby_binary_path_str = ruby_binary_path
-        .lines()
-        .next()
-        .expect("failed to execute ruby process");
-
-    ruby_binary_path_str.to_string()
-}
